baysea(y, period=12, span=4, shift=1, forecast=0, trend.order=2,
seasonal.order=1, year=0, month=1, out=0, rigid=1,
zersum=1, delta=7, alpha=0.01, beta=0.01, gamma=0.1,
spec=TRUE, plot=TRUE, separate.graphics=FALSE)seasonal.order is smaller than or equal to span.year)
}year=0 this parameter is ignored.trend, adjust, smoothed, season and irregular.year > 0.y-trend-season-tday-outlier.trend-irregular.trend+season+tday.acov (autocovariances), acor (normalized covariances), mean, v (innovation variance), aic (AIC), parcor (partial autocorrelation)
and rspec (rational spectrum) of irregular if spec=TRUE.acov, acor, mean, v, aic, parcor and rspec of differenced adjusted series if spec=TRUE.acov, acor, mean, v, aic and parcor of differenced trend series if spec=TRUE.acov, acor, mean, v, aic and parcor of differenced seasonal series if spec=TRUE.y into the form
$$y(t) = T(t) + S(t) + I(t) + TDC(t) + OCF(t)$$
where $T(t)$ is trend component, $S(t)$ is seasonal component, $I(t)$ is irregular, $TDC(t)$ is trading day factor and $OCF(t)$ is outlier correction factor.
For the purpose of comparison of models the criterion ABIC is defined
$$ABIC = -2(log\ maximum\ likelihood\ of\ the\ model).$$
Smaller value of ABIC represents better fit.data(LaborData)
baysea(LaborData, forecast=12)Run the code above in your browser using DataLab