plot.decomp: Plot Trend, Seasonal, AR Components and Trading Day Factor

View source: R/timsac84.R

plot.decompR Documentation

Plot Trend, Seasonal, AR Components and Trading Day Factor

Description

Plot trend component, seasonal component, AR component, noise and trading day factor returned by decomp.

Usage

## S3 method for class 'decomp'
plot(x, ...)

Arguments

x

an object of class "decomp".

...

further graphical parameters may also be supplied as arguments.


timsac documentation built on March 25, 2026, 9:06 a.m.